<?php

namespace Controller;

use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource;
use Service;
use Util\Messages;
use \Util\Utilities;

/**
 * Class ProjectTypeByProfile
 * @package Controller
 */
class ProjectTypeByProfile extends Simple
{

    /**
     * @var Service\ProjectTypeByProfile $projectTypeByProfileService
     */
    private $projectTypeByProfileService;

    /**
     * @var Utilities $utilities
     */
    private $utilities;

    /**
     * @var Service\Resource $resourceService
     */
    private $resourceService;

    public function __construct(\Util\Utilities $utilities, Service\ProjectTypeByProfile $projectTypeByProfileService,
                                Service\Resource $resourceService){
        $this->projectTypeByProfileService = $projectTypeByProfileService;
        $this->utilities = $utilities;
        $this->resourceService = $resourceService;
    }

    public function getProjectTypeByProfile(Request\Filter $request,Response $response){
        $organization = $this->utilities->getCurrentOrganizationId();
        $profiles = $this->utilities->getCurrentUserProfiles();
        if(empty($profiles)){
            $profiles = $this->resourceService->getProfileByCurrentUser();
        }

        $filters = $request->getFilterCriteria()->getConditions();
        $projectParentId = Utilities::getValueInFilterDataSourceByName($filters,'PROJECT_PARENT',true);
        $projectTypes = $this->projectTypeByProfileService->getProjectTypeByProfile($organization,$profiles,$filters,$projectParentId);

        $response->addDataset(new DataSet('projects', $projectTypes));
    }

    public function findProjectTypesForProjectFilter(Request $request,Response $response){

        $projectTypes = $this->projectTypeByProfileService->findProjectTypesForProjectFilter();

        $response->addDataset(new DataSet('projects', $projectTypes));
    }

}