<?php

namespace Service;


use Doctrine\ORM\EntityManager;
use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\DevOps\Model\Devops\Repositories;
use Zeedhi\DevOps\Model\Devops\Entities;

class ZhUserAllocation {

    protected $entityManager;
    protected $environment;
    /** @var \Factory\ZhUserAllocation  */
    protected $zhUserAllocationFactory;
    /** @var Repositories\ZhUserAllocation */
    protected $zhUserAllocationRepository;


    public function __construct(EntityManager $entityManager, \Util\Utilities $environment ,
                                \Factory\ZhUserAllocation $zhUserAllocationFactory){
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->zhUserAllocationFactory = $zhUserAllocationFactory;
        $this->zhUserAllocationRepository = $entityManager->getRepository(Utilities::DEVOPS_ENTITY_DIR . 'ZhUserAllocation');
    }

    public function saveManagerProduct($product,$users){
        $userIds = Utilities::getArrayByArrayObjectWithGet($users);
        foreach ($users as $user) {
            if(!empty($user)){
                /** @var Entities\ZhUserAllocation $zhUserAllocation */
                $zhUserAllocation = $this->zhUserAllocationRepository->findOneBy(array("user" => $user,
                    "product" => $product));
                $zhUserAllocation = $this->zhUserAllocationFactory->saveZhUserAllocation($zhUserAllocation,$user,$product);
                $this->entityManager->persist($zhUserAllocation);
            }
        }
        $this->entityManager->flush();
        /** @var Entities\ZhUserAllocation[] $zhUserAllocations */
        $zhUserAllocations = $this->zhUserAllocationRepository->findBy(array("product" => $product));
        foreach ($zhUserAllocations as $zhUserAllocation) {
            if(!in_array($zhUserAllocation->getUser()->getId(), $userIds)){
                $this->entityManager->remove($zhUserAllocation);
                $this->entityManager->flush();
            }
        }

    }

    public function removeManagerProduct($product,$users){
        if($product){
            $userIds = Utilities::getArrayByArrayObjectWithGet($users);
            /** @var Entities\ZhUserAllocation[] $zhUserAllocations */
            $zhUserAllocations = $this->zhUserAllocationRepository->findBy(array("product" => $product));
            if(count($zhUserAllocations) > 1){
                foreach ($zhUserAllocations as $zhUserAllocation) {
                    if(in_array($zhUserAllocation->getUser()->getId(), $userIds)){
                        $this->entityManager->remove($zhUserAllocation);
                    }
                }
            }
        }
    }

    public function removeManagerRelease($release,$users){
        if($release) {
            $userIds = Utilities::getArrayByArrayObjectWithGet($users);
            /** @var Entities\ZhUserAllocation[] $zhUserAllocations */
            $zhUserAllocations = $this->zhUserAllocationRepository->findBy(array("release" => $release));
            if (count($zhUserAllocations) > 1) {
                foreach ($zhUserAllocations as $zhUserAllocation) {
                    if (in_array($zhUserAllocation->getUser()->getId(), $userIds)) {
                        $this->entityManager->remove($zhUserAllocation);
                    }
                }
            }
        }
    }

    public function removeManagerSubRelease($subRelease,$users){
        if($subRelease) {
            $userIds = Utilities::getArrayByArrayObjectWithGet($users);
            /** @var Entities\ZhUserAllocation[] $zhUserAllocations */
            $zhUserAllocations = $this->zhUserAllocationRepository->findBy(array("subrelease" => $subRelease));
            if (count($zhUserAllocations) > 1) {
                foreach ($zhUserAllocations as $zhUserAllocation) {
                    if (in_array($zhUserAllocation->getUser()->getId(), $userIds)) {
                        $this->entityManager->remove($zhUserAllocation);
                    }
                }
            }
        }
    }

    public function createManagerProduct($product,$users){
        if($product) {
            foreach ($users as $user) {
                if (!empty($user)) {
                    /** @var Entities\ZhUserAllocation $zhUserAllocation */
                    $zhUserAllocation = $this->zhUserAllocationRepository->findOneBy(array("user" => $user,
                        "product" => $product));
                    if (empty($zhUserAllocation)) {
                        $zhUserAllocation = $this->zhUserAllocationFactory->saveZhUserAllocation($zhUserAllocation, $user, $product);
                        $this->entityManager->persist($zhUserAllocation);
                    }
                }
            }
        }
    }

    public function createManagerRelease($release,$users){
        if($release){
            foreach ($users as $user) {
                if(!empty($user)){
                    /** @var Entities\ZhUserAllocation $zhUserAllocation */
                    $zhUserAllocation = $this->zhUserAllocationRepository->findOneBy(array("user" => $user,
                        "release" => $release));
                    $zhUserAllocation = $this->zhUserAllocationFactory->saveZhUserAllocation($zhUserAllocation,$user,null,$release);
                    $this->entityManager->persist($zhUserAllocation);
                }
            }
        }
    }

    public function createManagerSubRelease($subRelease,$users){
        if($subRelease){
            foreach ($users as $user) {
                if(!empty($user)){
                    /** @var Entities\ZhUserAllocation $zhUserAllocation */
                    $zhUserAllocation = $this->zhUserAllocationRepository->findOneBy(array("user" => $user,
                        "subrelease" => $subRelease));
                    $zhUserAllocation = $this->zhUserAllocationFactory->saveZhUserAllocation($zhUserAllocation,$user,null,null,$subRelease);
                    $this->entityManager->persist($zhUserAllocation);
                }
            }
        }
    }

    public function saveManagerRelease($release,$users){
        $userIds = Utilities::getArrayByArrayObjectWithGet($users);
        foreach ($users as $user) {
            if(!empty($user)){
                /** @var Entities\ZhUserAllocation $zhUserAllocation */
                $zhUserAllocation = $this->zhUserAllocationRepository->findOneBy(array("user" => $user,
                    "release" => $release));
                $zhUserAllocation = $this->zhUserAllocationFactory->saveZhUserAllocation($zhUserAllocation,$user,null,$release);
                $this->entityManager->persist($zhUserAllocation);
            }
        }
        $this->entityManager->flush();
        /** @var Entities\ZhUserAllocation[] $zhUserAllocations */
        $zhUserAllocations = $this->zhUserAllocationRepository->findBy(array("release" => $release));
        foreach ($zhUserAllocations as $zhUserAllocation) {
            if(!in_array($zhUserAllocation->getUser()->getId(), $userIds)){
                $this->entityManager->remove($zhUserAllocation);
                $this->entityManager->flush();
            }
        }
    }

    public function saveManagerSubRelease($subRelease,$users){
        $userIds = Utilities::getArrayByArrayObjectWithGet($users);
        foreach ($users as $user) {
            if(!empty($user)){
                /** @var Entities\ZhUserAllocation $zhUserAllocation */
                $zhUserAllocation = $this->zhUserAllocationRepository->findOneBy(array("user" => $user,
                    "subrelease" => $subRelease));
                $zhUserAllocation = $this->zhUserAllocationFactory->saveZhUserAllocation($zhUserAllocation,$user,null,null,$subRelease);
                $this->entityManager->persist($zhUserAllocation);
            }
        }
        $this->entityManager->flush();
        /** @var Entities\ZhUserAllocation[] $zhUserAllocations */
        $zhUserAllocations = $this->zhUserAllocationRepository->findBy(array("subrelease" => $subRelease));
        foreach ($zhUserAllocations as $zhUserAllocation) {
            if(!in_array($zhUserAllocation->getUser()->getId(), $userIds)){
                $this->entityManager->remove($zhUserAllocation);
                $this->entityManager->flush();
            }
        }
    }


}